@@ -14,6 +14,9 @@
 #include <QList>
 #include <QObject>
 #include <QPair>
+
+#include <memory>
+
 class JobInfo
 {
 public:
@@ -41,6 +44,8 @@ public:
     QString stateAsString() const;
 };
 
+class JobTrackerPrivate;
+
 class LIBAKONADICONSOLE_EXPORT JobTracker : public QObject
 {
     Q_OBJECT
@@ -48,7 +53,7 @@ class LIBAKONADICONSOLE_EXPORT JobTracker : public QObject
 
 public:
     explicit JobTracker(const char *name, QObject *parent = nullptr);
-    ~JobTracker();
+    ~JobTracker() override;
 
     QStringList sessions() const;
 
@@ -106,7 +111,7 @@ private:
     QVector<int> childJobs(int parentId) const;
     int idForJob(const QString &job) const;
 
-    class Private;
-    Private *const d;
+private:
+    std::unique_ptr<JobTrackerPrivate> const d;
 };
 
