@@ -72,9 +72,7 @@ private:
     class Node
     {
     public:
-        virtual ~Node()
-        {
-        }
+        virtual ~Node() = default;
 
         Node *parent;
         RowType type;
@@ -250,7 +248,7 @@ public:
         }
     }
 
-    int rowCount(const QModelIndex &parent) const override
+    Q_REQUIRED_RESULT int rowCount(const QModelIndex &parent) const override
     {
         if (!parent.isValid()) {
             return mConnections.count();
@@ -269,22 +267,22 @@ public:
         Q_UNREACHABLE();
     }
 
-    int columnCount(const QModelIndex &parent = QModelIndex()) const override
+    Q_REQUIRED_RESULT int columnCount(const QModelIndex &parent = QModelIndex()) const override
     {
         Q_UNUSED(parent)
         return 5;
     }
 
-    QModelIndex parent(const QModelIndex &child) const override
+    Q_REQUIRED_RESULT QModelIndex parent(const QModelIndex &child) const override
     {
         if (!child.isValid() || !child.internalPointer()) {
-            return QModelIndex();
+            return {};
         }
 
         Node *childNode = reinterpret_cast<Node *>(child.internalPointer());
         // childNode is a Connection
         if (!childNode->parent) {
-            return QModelIndex();
+            return {};
         }
 
         // childNode is a query in transaction
@@ -298,13 +296,13 @@ public:
         }
     }
 
-    QModelIndex index(int row, int column, const QModelIndex &parent) const override
+    Q_REQUIRED_RESULT QModelIndex index(int row, int column, const QModelIndex &parent) const override
     {
         if (!parent.isValid()) {
             if (row < mConnections.count()) {
                 return createIndex(row, column, mConnections.at(row));
             } else {
-                return QModelIndex();
+                return {};
             }
         }
 
@@ -314,26 +312,26 @@ public:
             if (row < static_cast<ConnectionNode *>(parentNode)->queries.count()) {
                 return createIndex(row, column, static_cast<ConnectionNode *>(parentNode)->queries.at(row));
             } else {
-                return QModelIndex();
+                return {};
             }
         case Transaction:
             if (row < static_cast<TransactionNode *>(parentNode)->queries.count()) {
                 return createIndex(row, column, static_cast<TransactionNode *>(parentNode)->queries.at(row));
             } else {
-                return QModelIndex();
+                return {};
             }
         case Query:
             // Query can never have children
-            return QModelIndex();
+            return {};
         }
 
         Q_UNREACHABLE();
     }
 
-    QVariant headerData(int section, Qt::Orientation orientation, int role) const override
+    Q_REQUIRED_RESULT QVariant headerData(int section, Qt::Orientation orientation, int role) const override
     {
         if (orientation != Qt::Horizontal || role != Qt::DisplayRole) {
-            return QVariant();
+            return {};
         }
 
         switch (section) {
@@ -349,13 +347,13 @@ public:
             return QStringLiteral("Error");
         }
 
-        return QVariant();
+        return {};
     }
 
-    QVariant data(const QModelIndex &index, int role) const override
+    Q_REQUIRED_RESULT QVariant data(const QModelIndex &index, int role) const override
     {
         if (!index.isValid()) {
-            return QVariant();
+            return {};
         }
 
         Node *node = reinterpret_cast<Node *>(index.internalPointer());
@@ -419,7 +417,7 @@ public:
     }
 
 private:
-    QString fromMSecsSinceEpoch(qint64 msecs) const
+    Q_REQUIRED_RESULT QString fromMSecsSinceEpoch(qint64 msecs) const
     {
         return QDateTime::fromMSecsSinceEpoch(msecs).toString(QStringLiteral("dd.MM.yyyy HH:mm:ss.zzz"));
     }
@@ -427,7 +425,7 @@ private:
     QVariant connectionData(ConnectionNode *connection, int column, int role) const
     {
         if (role != Qt::DisplayRole) {
-            return QVariant();
+            return {};
         }
 
         switch (column) {
@@ -437,7 +435,7 @@ private:
             return fromMSecsSinceEpoch(connection->start);
         }
 
-        return QVariant();
+        return {};
     }
 
     QVariant transactionData(TransactionNode *transaction, int column, int role) const
@@ -493,7 +491,7 @@ private:
             return query->values;
         }
 
-        return QVariant();
+        return {};
     }
 
     QVector<ConnectionNode *> mConnections;
@@ -515,10 +513,10 @@ public:
     enum SPECIAL_ROWS { TOTAL, NUM_SPECIAL_ROWS };
     enum COLUMNS { DurationColumn, CallsColumn, AvgDurationColumn, QueryColumn, NUM_COLUMNS };
 
-    QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const override
+    Q_REQUIRED_RESULT QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const override
     {
         if (orientation == Qt::Vertical || section < 0 || section >= NUM_COLUMNS || (role != Qt::DisplayRole && role != Qt::ToolTipRole)) {
-            return QVariant();
+            return {};
         }
 
         if (section == QueryColumn) {
@@ -531,22 +529,22 @@ public:
             return QStringLiteral("Avg. Duration [ms]");
         }
 
-        return QVariant();
+        return {};
     }
 
-    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override
+    Q_REQUIRED_RESULT QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override
     {
         if (role != Qt::DisplayRole && role != Qt::ToolTipRole) {
-            return QVariant();
+            return {};
         }
 
         const int row = index.row();
         if (row < 0 || row >= rowCount(index.parent())) {
-            return QVariant();
+            return {};
         }
         const int column = index.column();
         if (column < 0 || column >= NUM_COLUMNS) {
-            return QVariant();
+            return {};
         }
 
         const QueryInfo &info = (row < NUM_SPECIAL_ROWS) ? mSpecialRows[row] : mQueries.at(row - NUM_SPECIAL_ROWS);
@@ -565,10 +563,10 @@ public:
             return float(info.duration) / info.calls;
         }
 
-        return QVariant();
+        return {};
     }
 
-    int rowCount(const QModelIndex &parent = QModelIndex()) const override
+    Q_REQUIRED_RESULT int rowCount(const QModelIndex &parent = QModelIndex()) const override
     {
         if (!parent.isValid()) {
             return mQueries.size() + NUM_SPECIAL_ROWS;
@@ -577,7 +575,7 @@ public:
         }
     }
 
-    int columnCount(const QModelIndex &parent = QModelIndex()) const override
+    Q_REQUIRED_RESULT int columnCount(const QModelIndex &parent = QModelIndex()) const override
     {
         if (!parent.isValid()) {
             return NUM_COLUMNS;
